﻿© Fluke Calibration. All Rights Reserved.                  MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub UUT Connection VISA
DATE:                  2011-11-10 10:49:03
AUTHOR:                Fluke
REVISION:              $Revision: 23501 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       188
=============================================================================
#
#  Procedure Author:
#        DAC, DFM, CAD
#
#  Models covered:
#        All with any of the following interface:
#          USBTMC
#          LAN (Ethernet), VXI-11 compliant only
#          IEEE-488
#          RS-232C
#
#  Compatibility:
#        MET/CAL 7.20 SP1 (7.20x) or later
#
#  Subprocedures:
#        None
#
#  Required Files:
#        None
#
#  Required Equipment:
#        None
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
#  Global Variables:
#    @VisaUSB    Boolean: UUT has a USBTMC compliant USB interface
#    @VisaLAN    Boolean: UUT has a VXI-11 compliant Ethernet interface
#    @Visa488    Boolean: UUT has an IEEE-488 interface
#    @VisaRS232  Boolean: UUT has an RS-232 interface
#
#  Various trademarks are property of their respective owners.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# Initialize interface variables not specified in the calling procedure.
  1.001  IF           NOT(ISVAR("@VisaUSB"))
  1.002  MATH         @VisaUSB = 0
  1.003  ENDIF

  1.004  IF           NOT(ISVAR("@VisaLAN"))
  1.005  MATH         @VisaLAN = 0
  1.006  ENDIF

  1.007  IF           NOT(ISVAR("@Visa488"))
  1.008  MATH         @Visa488 = 0
  1.009  ENDIF

  1.010  IF           NOT(ISVAR("@VisaRS232"))
  1.011  MATH         @VisaRS232 = 0
  1.012  ENDIF

# Make sure at least one support interface was specified.
  1.013  IF           NOT(@VisaUSB || @VisaLAN || @Visa488 || @VisaRS232)
  1.014  DISP         For "Sub UUT Connection VISA" to function, at least
  1.014  DISP         one of the variables, @VisaUSB, @VisaLAN, @Visa488,
  1.014  DISP         or @VisaRS232 must be true (1).
  1.015  MATH         @Abort = 1
  1.016  ENDIF

  1.017  MATH         USB = 0; LAN = 0; GPIB = 0; Serial = 0

# If only one interface is supported by the UUT, choose it.
  1.018  IF           @VisaUSB && NOT(@VisaLAN || @Visa488 || @VisaRS232)
  1.019  MATH         USB = 1

  1.020  ELSEIF       @VisaLAN && NOT(@VisaUSB || @Visa488 || @VisaRS232)
  1.021  MATH         LAN = 1

  1.022  ELSEIF       @Visa488 && NOT(@VisaUSB || @VisaLAN || @VisaRS232)
  1.023  MATH         GPIB = 1

  1.024  ELSEIF       @VisaRS232 && NOT(@VisaUSB || @VisaLAN || @Visa488)
  1.025  MATH         Serial = 1

# Otherwise allow operator to select the UUT interface to use.
  1.026  ELSE
  1.027  MATH         @Id = LBNEW("UUT REMOTE CONTROL INTERFACE")
  1.028  MEM2         =Select UUT interface to be used for calibration.
  1.029  MATH         LBTEXT(@Id, MEM2)
  1.030  MATH         LBCONF(@Id, "+SelReq")
  1.031  MATH         LBBUTTON(@Id, "OK")
  1.032  MATH         LBBUTTON(@Id, "Exit")

  1.033  IF           @VisaUSB
  1.034  MATH         LBADDV(@Id, "USB", "USB")
  1.035  ENDIF

  1.036  IF           @VisaLAN
  1.037  MATH         LBADDV(@Id, "LAN (Ethernet)", "LAN")
  1.038  ENDIF

  1.039  IF           @Visa488
  1.040  MATH         LBADDV(@Id, "IEEE-488 (GPIB)", "GPIB")
  1.041  ENDIF

  1.042  IF           @VisaRS232
  1.043  MATH         LBADDV(@Id, "RS-232C (Serial)", "Serial")
  1.044  ENDIF

# Return now if operator selected "Exit".
  1.045  IF           LBSHOW(@Id) == 2
  1.046  MATH         @Abort = 1
  1.047  END
  1.048  ENDIF

  1.049  ENDIF

# Display an appropriate message based on the UUT interface selected.
  1.050  IF           USB
  1.051  DISP         Connect UUT to an available PC USB port using an
  1.051  DISP         appropriate cable.
  1.051  DISP
  1.051  DISP         Ensure the Windows® operating system recognizes the
  1.051  DISP         "plug-and-play" device prior to proceeding.

  1.052  DISP         Optionally, NI® Measurement & Automation Explorer (MAX)
  1.052  DISP         may be used to verify the USB connection, following the
  1.052  DISP         operating system's recognition of the device.

  1.053  ELSEIF       LAN
  1.054  DISP         Using an appropriate cable, connect the LAN (Ethernet,
  1.054  DISP         TCP/IP) to the UUT.
  1.054  DISP
  1.054  DISP         Configure the UUT for LAN operation in accordance with
  1.054  DISP         the manufacturer's instructions.

  1.055  DISP         NI® Measurement & Automation Explorer (MAX) MUST be
  1.055  DISP         used to establish a VISA resource name for the UUT,
  1.055  DISP         prior to proceeding.
  1.055  DISP
  1.055  DISP         Optionally, NI MAX may also be used to subsequently
  1.055  DISP         verify the UUT connection.

  1.056  ELSEIF       GPIB
  1.057  DISP         Connect UUT to GPIB port 0 or 1.
  1.057  DISP
  1.057  DISP         If the UUT is connected to GPIB port 0, ensure its
  1.057  DISP         address does not conflict with the address of any
  1.057  DISP         reference previously configured on the port.

  1.058  ELSEIF       Serial
  1.059  MATH         MEM2 = INI("startup", "port")

  1.060  MATH         L[1] = ZCMPI(MEM2, "COM5500")
  1.061  MATH         L[1] = ZCMPI(MEM2, "COM5520") || L[1]
  1.062  MATH         L[1] = ZCMPI(MEM2, "COM5800") || L[1]
  1.063  MATH         L[1] = ZCMPI(MEM2, "COM5820") || L[1]

  1.064  IF           L[1]
  1.065  DISP         Unsupported UUT communication port specified: [MEM2]
  1.065  DISP
  1.065  DISP         Select "Terminate" and perform the following:
  1.065  DISP
  1.065  DISP         - From the menu bar, select
  1.065  DISP         [32] "Configure"=>"Default Serial Port"
  1.065  DISP
  1.065  DISP         - Select a PC COMM port: "COM1",... "COM16"
  1.066  MATH         @Abort = 1
  1.067  ENDIF

  1.068  DISP         Connect UUT to [MEM2] using an appropriate serial
  1.068  DISP         interface cable.
  1.068  DISP
  1.068  DISP         You must ensure that ALL serial communication parameters
  1.068  DISP         agree between the UUT and [MEM2]. This includes baud
  1.068  DISP         rate, data bits, parity, stop bits, and flow control.
  1.068  DISP
  1.068  DISP         Optionally, NI® Measurement & Automation Explorer (MAX)
  1.068  DISP         may subsequently be used to verify the UUT connection.
  1.069  ENDIF

  1.070  MATH         @Abort = 0
  1.071  END