﻿Copyright (c) (2016) Fluke Corporation                      MET/CAL Procedure
=============================================================================
INSTRUMENT:            Tek TPA-N-PRE: (1 yr) DANL VER VISA /EPM,SWPG
DATE:                  2017-02-08 09:51:24
AUTHOR:                Fluke
REVISION:              $Revision: 25369 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       298
CONFIGURATION:         Agilent EPM
CONFIGURATION:         Agilent E9304A on channel 1
CONFIGURATION:         Sweep Generator
STANDARD:              HP 11667A
STANDARD:              50 Ohm Termination
=============================================================================
#
#  Procedure Author:
#        CAD
#
#  Models covered:
#        Tektronix TPA-N-PRE Preamplifier for the MDO4000 Series
#
#  Source(s):
#        MDO4000 Series Mixed Domain Oscilloscopes
#        Specifications and Performance Verification Technical Reference
#        PN 077-0583-02
#
#  Flexible Standard(s) Required:
#
#        Synthesized Sweep Generator (SWPG):
#          Frequency Range:       50 kHz to 6 GHz
#          Frequency Accuracy:    ± 5 ppm
#          Amplitude Range:       -15 dBm to +10 dBm
#          Amplitude Resolution:  1 dB
#          Example: R&S SMF100A
#
#  Additional Equipment Required:
#        Any one of the following: MDO4014-3, MDO4034-3, MDO4054-3, MDO4054-6,
#          MDO4104-3, or MDO4104-6.
#        Note: -6 model required to test full frequency range of UUT.
#
#        Power Splitter (HP 11667A):
#          Frequency Range:       DC to 6 GHz
#          Impedance:             50 Ω
#          Equivalent Output SWR:    DC to 4 GHz: < 1.10
#                                 4 GHz to 6 GHz: < 1.20
#          Output Tracking:          DC to 4 GHz: < 0.15 dB
#                                 4 GHz to 6 GHz: < 0.20 dB
#
#  This procedure is intended for use with MET/CAL® calibration software;
#  the terms and conditions set forth in your MET/CAL license apply to this
#  procedure.
#
#  Due to Fluke's policy of continuously updating our products, this procedure
#  may contain minor differences in methods used and/or specifications to
#  those found in the manual or other documentation. While every effort has
#  been made to ensure that this procedure is accurate, Fluke cannot be held
#  responsible for the consequences of error or omissions found within this
#  procedure.
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# These statements are here to force the procedure header to list the
# instrument configuration required by the subprocedures.
  1.001  IF           0
  1.002  IEEE         [@SWPG]
  1.003  EPM          Zero_and_Cal; PowerSensorA = E9304A
  1.004  STD          HP 11667A
  1.005  ENDIF

  1.006  ASK-   R   Q N              P                            A        V

  1.007  IF           NOT(VERSIONCHECK("7.3.38"))
  1.008  END
  1.009  ENDIF

  1.010  CALL         Sub MET/CAL Initialization Parameter "acc_check"
  1.011  JMPL         END                          @Abort

  1.012  CALL         Sub Display Copyright

  1.013  MATH         @VisaUSB = 1; @VisaLAN = 1
  1.014  CALL         Sub Tek MDO4000 Remote Interface Connection
  1.015  JMPL         END                          @Abort

  1.016  VISA         *RST

  1.017  CALL         Sub IEEE-488.2 Identification Query VISA
  1.018  MATH         @UUT_Manufacturer = "Tektronix"
  1.019  CALL         Sub IEEE-488.2 Identification Query Check Response
  1.020  MATH         @Abort = NOT(FINDI(@ModelNum, "MDO", 0))
  1.021  JMPL         END                          @Abort

# Establish maximum test frequency based on the MDO model being used.
  1.022  IF           FINDI(@ModelNum, "-3", 0)
  1.023  MATH         @UUT_MaxFreq = 3E+9
  1.024  ELSE
  1.025  MATH         @UUT_MaxFreq = 6E+9
  1.026  ENDIF

  1.027  IF           @FirmwareRev < 2.94
  1.028  DISP         This procedure requires UUT firmware version 2.94 or
  1.028  DISP         later.
  1.028  DISP
  1.028  DISP         The UUT's installed firmware is [V @FirmwareRev].
  1.028  DISP
  1.028  DISP         For firmware upgrades, please visit http://www.tek.com.
  1.028  DISP         Firmware files and installation instructions are
  1.028  DISP         available for download.
  1.029  END
  1.030  ENDIF

  1.031  HEAD         PRELIMINARY INSTRUCTIONS
  1.032  TARGET
  1.033  DISP         Ensure a minimum UUT warm-up time of at least
  1.033  DISP         20 minutes has been allowed to elapse, prior
  1.033  DISP         to beginning verification.

  1.034  CALL         Sub Initialize /SWPG

  1.035  DISP         The minimum use specifications of the following device,
  1.035  DISP         configured as flexible standards, must be satisfied.
  1.035  DISP
  1.035  DISP         [32]NOMENCLATURE        ALIAS   DEVICE NAME
  1.035  DISP
  1.035  DISP         [32]Sweep Generator     SWPG   [V @SWPG_DevName]

  1.036  HEAD         -2 (Synthesized) Sweep Generator (SWPG)
  1.037  OPBR         -z SWPG: [V @SWPG_DevName] Minimum Use
  1.037  OPBR         Specifications:
  1.037  OPBR
  1.037  OPBR         Frequency:
  1.037  OPBR         - Range:      50 kHz to [V @UUT_MaxFreq], CW
  1.037  OPBR         - Accuracy:   ± 5 ppm
  1.037  OPBR
  1.037  OPBR         Amplitude:
  1.037  OPBR         - Range:      -15 dBm to +10 dBm
  1.037  OPBR         - Resolution: 1 dB
  1.037  OPBR
  1.037  OPBR         Does the [V @SWPG_DevName] satisfy the above Minimum
  1.037  OPBR         Use Specifications?[NO]

  1.038  IF           NOT(MEM1)
  1.039  HEAD         FLEXIBLE STANDARD(S) UNSATISFACTORY FOR PROCEDURE USE!
  1.040  DISP         Flexible Standard(s) currently configured for use with
  1.040  DISP         this procedure have been identified as not satisfying
  1.040  DISP         the Minimum Use Specifications.
  1.040  DISP
  1.040  DISP         Select "Advance" to abort procedure, configure suitable
  1.040  DISP         devices, then restart the procedure from the beginning.
  1.041  END
  1.042  ENDIF

  1.043  OPBR         -z Do you want to REVIEW the list of additional
  1.043  OPBR         equipment and/or accessories required?

  1.044  IF           MEM1
  1.045  HEAD         ADDITIONAL EQUIPMENT/ACCESSORIES REQUIRED
  1.046  HEAD         -2 Power Splitter
  1.047  DISP         Additional equipment required (no substitute):
  1.047  DISP
  1.047  DISP         Power Splitter (HP 11667A):
  1.047  DISP
  1.047  DISP         Frequency Range: DC to 6 GHz
  1.047  DISP         Impedance:       50 Ω
  1.047  DISP
  1.047  DISP         Equivalent Output SWR:
  1.047  DISP         - 10.0 MHz to 3.6 GHz: < 1.10
  1.047  DISP         -  3.6 GHz to 6.0 GHz: < 1.30
  1.047  DISP
  1.047  DISP         Level Imbalance:
  1.047  DISP         - 10.0 MHz to 3.6 GHz: < 0.1 dB
  1.047  DISP         -  3.6 GHz to 6.0 GHz: < 0.3 dB

  1.048  HEAD         -2 Additional Equipment/Accessories
  1.049  DISP         Additional Equipment/Accessories Required
  1.049  DISP         (or equivalent):
  1.049  DISP
  1.049  DISP         Termination (Agilent 909D):
  1.049  DISP         - Frequency: 10 MHz to [V @UUT_MaxFreq]
  1.049  DISP         - Impedance: 50 Ω
  1.049  DISP         - Connector: Type N (m)
  1.049  DISP
  1.049  DISP         Adapters:
  1.049  DISP         - <tbd>
  1.049  DISP
  1.049  DISP         Cables:
  1.049  DISP         - <tbd>
  1.050  ENDIF

  1.051  HEAD         CONNECTOR INFORMATION
  1.052  OPBR         -z Do you wish to review connector information and
  1.052  OPBR         precautions for the various types of connections
  1.052  OPBR         employed throughout this procedure?[NO]

  1.053  IF           MEM1
  1.054  CALL         Sub Connector Precautions (Type N)
  1.055  CALL         Sub Connector Precautions (SMA)
  1.056  ENDIF

  1.057  HEAD         SETUP PROCEDURE EXECUTION PARAMETERS
  1.058  CALL         Sub Select Failed Test Mode
  1.059  CALL         Sub Select Verification Method (No NTHROW)

  1.060  RSLT         =
  1.061  HEAD         FUNCTION CHECKS FOR TPA-N-PRE/MDO4000 SYSTEM
  1.062  MATH         @Splitter = "HP 11667A"
  1.063  TARGET

  1.064  CALL         Sub Initialize /SWPG
  1.065  CALL         Sub Reset /SWPG
  1.066  CALL         Sub Output Off /SWPG

  1.067  PIC          tpa-n-pre_splitter_epm_swpg.png

  1.068  VISA         *RST;*OPC?[I!]
  1.069  VISA         ACQUIRE:STATE OFF;STOPAFTER SEQUENCE
  1.070  VISA         HEADER OFF;:CLEARM;:SEL:CH1 OFF
  1.071  VISA         SEL:RF_NORM ON;:RF:UNITS DBM;SPAN 50E+6
# Configure UUT automatic marker system.
  1.072  VISA         MARKER:PEAK:STATE ON;THR -150;EXCUR 0;MAX 1
  1.073  VISA         MARKER:TYPE ABS
  1.074  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  1.075  JMPL         END                          @Abort

  1.076  MATH         @Freq = "1.7 GHz"; @Level = "-30 dBm"; @RefLevel = -25
  1.077  CALL         Sub Tek TPA-N-PRE DANL Function Check VISA /EPM,SWPG
  1.078  JMPL         END                          @Abort

  1.079  MATH         @Freq = "1.7 GHz"; @Level = "-45 dBm"; @RefLevel = -40
  1.080  CALL         Sub Tek TPA-N-PRE DANL Function Check VISA /EPM,SWPG
  1.081  JMPL         END                          @Abort

  1.082  IF           BASE(@UUT_MaxFreq) > 3E+9
  1.083  MATH         @Freq = "5.5 GHz"; @Level = "-30 dBm"; @RefLevel = -25
  1.084  CALL         Sub Tek TPA-N-PRE DANL Function Check VISA /EPM,SWPG
  1.085  JMPL         END                          @Abort

  1.086  MATH         @Freq = "5.5 GHz"; @Level = "-45 dBm"; @RefLevel = -40
  1.087  CALL         Sub Tek TPA-N-PRE DANL Function Check VISA /EPM,SWPG
  1.088  JMPL         END                          @Abort
  1.089  ENDIF

  1.090  STD          50 Ohm Termination
  1.091  RSLT         =
  1.092  HEAD         {DISPLAYED AVERAGE NOISE LEVEL (DANL)}
  1.093  TARGET       -p
  1.094  DISP         Connect a 50 Ohm, DC to [V @UUT_MaxFreq] SMA termination
  1.094  DISP         to the TPA-N-PRE Preamplifier INPUT.

  1.095  VISA         *RST;*OPC?[I!]
  1.096  VISA         ACQUIRE:STATE OFF;STOPAFTER SEQUENCE
  1.097  VISA         HEADER OFF;:CLEARM;:SEL:CH1 OFF
# Configure oscilloscope acquisition system for average mode.
  1.098  VISA         ACQ:MODE AVE;NUMAV 16
  1.099  VISA         SEL:RF_AVE ON;RF_NORM OFF
  1.100  VISA         RF:DETECTIONMETHOD:MODE MANUAL;RF_AVERAGE AVERAGE
  1.101  VISA         RF:UNITS DBM;REFLEVEL -40
# Configure UUT automatic marker system.
  1.102  VISA         MARKER:PEAK:STATE ON;THR -150;EXCUR 0;MAX 1
  1.103  VISA         MARKER:TYPE ABS
  1.104  CALL         Sub Tek MDO/MSO/DPO Wait for OPC VISA
  1.105  JMPL         END                          @Abort

  1.106  MATH         @Span  = ""
  1.107  MATH         @Start = "50 kHz"; @Stop = "5 MHz"; @Limit = -140
  1.108  CALL         Sub Tektronix TPA-N-PRE DANL Test VISA
  1.109  JMPL         END                          @Abort

  1.110  MATH         @Span  = "10 MHz"
  1.111  MATH         @Start = "5 MHz";  @Stop = "3 GHz"; @Limit = -158
  1.112  CALL         Sub Tektronix TPA-N-PRE DANL Test VISA
  1.113  JMPL         END                          @Abort

  1.114  IF           BASE(@UUT_MaxFreq) <= 3E+9
  1.115  RSLT         =TPA-N-PRE Preamplifier not tested above 3 GHz.

  1.116  ELSE
  1.117  MATH         @Start = "3 GHz";  @Stop = "4 GHz"; @Limit = -150
  1.118  CALL         Sub Tektronix TPA-N-PRE DANL Test VISA
  1.119  JMPL         END                          @Abort

  1.120  MATH         @Start = "4 GHz";  @Stop = "6 GHz"; @Limit = -150
  1.121  CALL         Sub Tektronix TPA-N-PRE DANL Test VISA
  1.122  ENDIF

  1.123  LABEL        END
  1.124  VISA         *RST

  1.125  IF           @Abort
  1.126  HEAD         {V E R I F I C A T I O N   A B O R T E D}
  1.127  ELSE
  1.128  HEAD         V E R I F I C A T I O N   C O M P L E T E
  1.129  ENDIF

  1.130  END
